@@ -7,11 +7,10 @@ from typing import List, Any, Union
 
 from superbsapi import *
 
+from .BaseDB import BaseDB
 from .exception import DBError, DataError
-from utils.conf.db_error import BS_NOERROR
-from utils.conf.constants import *
-from utils.conf.def_tree import *
-from utils.conf.mxconfig import MxConfig
+from .db_def.def_type import *
+from .db_def.def_tree import *
 
 symbol_map = {
     'e': TRDB_FMC_EQUAL,  # 等于
@@ -27,76 +26,9 @@ symbol_map = {
     'between': TRDB_FMC_RANGE  # 范围查找（范围）
     # 其他的类型，以后用到了再添加
 }
-type_map = {
-    'str': VDT_STR,
-    'float': VDT_FLOAT,
-    'double': VDT_DOUBLE,
-    'int': VDT_I32,
-    'int8': VDT_I8,
-    'int64': VDT_I64,
-
-    'ui8': VDT_UI8,
-    'ui64': VDT_UI64,
-    'time': VDT_TIME,
-    'timestr': VDT_TIMESTR,
-    'empty': VDT_EMPTY
-    # 其他的类型，以后用到了再添加
-}
 
 
-class TreeDB(object):
-
-    def __init__(self, *args, **kwargs) -> None:
-        self.__chl = CBSHandleLoc()
-
-    @staticmethod
-    def return_value(res: tuple) -> Union[int, tuple, None]:
-        """
-        用于直接返回结果集的函数，处理其返回值
-
-        :param res: 错误信息及函数返回的数据
-        :return: 返回信息
-        """
-        msg = res[0] if isinstance(res, tuple) else res
-        if msg != BS_NOERROR:
-            raise DBError(msg)
-        if res:
-            return res[1] if len(res) == 2 else res[1:]
-        return None
-
-    def exec_tree(self, operate: str, *args: Any, **kwargs: Any) -> Union[int, tuple, None]:
-        """
-        用于执行Tree db开头的函数
-
-        :param operate: 使用的函数
-        :param args kwargs: 函数所使用的变量
-        :return: 执行结果
-        """
-        func = getattr(self.__chl, operate)
-        res = func(*args, **kwargs)
-        return self.return_value(res)
-
-    def exec_bs(self, operate: str, *args: Any, **kwargs: Any) -> Union[int, str, tuple, None]:
-        """
-        用于执行bs开头的函数
-
-        :param operate: 使用的函数
-        :param args kwargs: 函数所使用的变量
-        :return: 执行结果
-        """
-        res = eval(operate)(self.__chl.GetConfHandle(), *args, **kwargs)
-        return self.return_value(res)
-
-    def exec_class(self, operator: str, *args, **kwargs):
-        """
-        用于执行类方法
-
-        :param operator: 使用的函数
-        :return: 执行结果
-        """
-        func = getattr(CBSHandleLoc, operator)
-        res = func(*args, **kwargs)
-        return self.return_value(res)
+class TreeDB(BaseDB):
 
     def begin(self) -> int:
         """
@@ -137,8 +69,8 @@ class TreeDB(object):
         # TODO 用到了再写吧
         # return self.exec_bs('bs_treedb_delete_index')
 
-    def open(self, main_key: str, sub_key: str = None, host: str = MxConfig.HOST, file: str = 'base',
-             main_key_pwd: str = '', flag: int = None, port: int = MxConfig.PORT, path_flag: bool = False) -> "TreeDB":
+    def open(self, main_key: str, sub_key: str = None, host: str = None, file: str = 'base',
+             main_key_pwd: str = '', flag: int = None, port: int = None, path_flag: bool = False) -> "TreeDB":
         """
         打开数据库键 [只打开主键或子键 / 同时打开主键和子键（子键路径）]
         eg: db = TreeModel()
@@ -154,6 +86,9 @@ class TreeDB(object):
         :param path_flag: 如果路径上有子键不存在是否自动创建
         :return: 类对象
         """
+        host = host or self.host
+        port = port or self.port
+
         if not flag:
             if sub_key:
                 flag = TRDB_OPKF_OPENEXIST if '\\' in sub_key else TRDB_OPKF_DOTPATH
@@ -186,7 +121,7 @@ class TreeDB(object):
                         raise DBError(e.err_code, '打开主键[%s]时' % main_key)
         return self
 
-    def main_keys(self, host: str = MxConfig.HOST, file: str = 'base', port: int = MxConfig.PORT) -> list:
+    def main_keys(self, host: str = None, file: str = 'base', port: int = None) -> list:
         """
         获取所有主键
         eg: sub_keys = db.open('MXSE', '1.SD', file='ccubase').main_keys()
@@ -196,6 +131,9 @@ class TreeDB(object):
         :param port: 端口号
         :return: 主键列表
         """
+        host = host or self.host
+        port = port or self.port
+
         res_list = list()
         self.exec_tree('Treedb_GetAllMainKeyNames', res_list, host, file, port)
         return res_list
@@ -302,20 +240,10 @@ class TreeDB(object):
         :param overwrite: 是否覆盖原值
         """
         value_type = type_map.get(value_type) or type_map.get(type(value).__name__)
-        assert value_type, '未知的value_type, 类型：%s ,值：%s' % (str(type(value)), value)
+        if not value_type:
+            raise DataError('未知的value_type, 类型：%s ,值：%s' % (str(type(value)), value))
         return self.exec_bs('bs_treedb_insert_property', prop, value, value_type, overwrite)
 
-    @staticmethod
-    def _check_item(item: tuple) -> int:
-        """
-        校验item是否符合数据要求并返回value type
-        """
-        assert isinstance(item, tuple) and len(item) in [2, 3], '错误的数据类型，items列表中的数据应为元组且长度为2或3'
-        assert type_map.get(item[2]) if len(item) == 3 else type_map.get(
-            type(item[1]).__name__), '无法获取到value的类型！如果您未手动传入类型或确信传入类型正确，请于文件首部type_map中添加此类型'
-        value_type = type_map[item[2]] if len(item) == 3 else type_map[type(item[1]).__name__]
-        return value_type
-
     def insert_items(self, items: List[tuple], overwrite=True) -> int:
         """
         批量插入数据
@@ -324,7 +252,8 @@ class TreeDB(object):
         :param items: 插入的数据
         :param overwrite: 是否覆盖原值
         """
-        assert isinstance(items, list), '错误的数据类型，items应为列表'
+        if not isinstance(items, list):
+            raise DataError('错误的数据类型，items应为列表')
         data_list = list()
         for item in items:
             data_list.append({'name': item[0], 'value': item[1], 'valuetype': self._check_item(item)})
@@ -343,7 +272,8 @@ class TreeDB(object):
         """
         if isinstance(items, tuple):
             items = [items]
-        assert isinstance(items, list), '错误的数据类型，items应为列表'
+        if not isinstance(items, list):
+            raise DataError('错误的数据类型，items应为列表')
         items_list = list()
         for item in items:
             items_list.append({'name': item[0], 'value': item[1], 'valuetype': self._check_item(item)})
@@ -417,7 +347,7 @@ class TreeDB(object):
                         default_expression：手动传入条件关系，默认关系为 and
         :return: 总条数，查询结果
         """
-        import re
+
         try:
             page_size = kwargs.pop('page_size')
             assert page_size, '未获取到数据！'
@@ -451,7 +381,7 @@ class TreeDB(object):
             try:
                 key, symbol = key.rsplit('__', 1)
                 if symbol not in symbol_map:
-                    raise DataError('查询操作错误！正确操作包含：gt、lt等，详情见TreeModel使用手册')
+                    raise DataError('查询操作错误！正确操作包含：gt、lt等')
             except ValueError:
                 symbol = 'e'
 
@@ -459,8 +389,10 @@ class TreeDB(object):
 
             if symbol == 'in':
                 j = 0
-                assert isinstance(value, list), '查询格式错误！正确示例：a__in=[1, 3, 4, 5]，详情见TreeModel使用手册'
-                assert len(value) != 0, '使用in时列表不能为空'
+                if not isinstance(value, list):
+                    raise DataError('查询格式错误！正确示例：a__in=[1, 3, 4, 5]')
+                if len(value) == 0:
+                    raise DataError('使用in时列表不能为空')
                 for v in value:
                     temp = {'key': key, 'value_type': type(v).__name__, 'symbol': 'e', 'value': v}
                     args.append(temp)
@@ -473,7 +405,8 @@ class TreeDB(object):
                 expression_temp += ')'
                 expression_list.append(expression_temp)
             elif symbol == 'between':
-                assert isinstance(value, list) and len(value) in [2, 3], '查询格式错误！正确示例：a__between=[1, 3]，详情见TreeModel使用手册'
+                if not isinstance(value, list) or len(value) not in [2, 3]:
+                    raise DataError('查询格式错误！正确示例：a__between=[1, 3]，详情见TreeModel使用手册')
                 temp['range_conditions'] = {'vLiData': value[0], 'vEnd': value[1]}
                 temp['value_type'] = value[2] if len(value) == 3 else type(value[0]).__name__
                 expression_list.append(' %s ' % i)
@@ -486,8 +419,10 @@ class TreeDB(object):
 
         default_query_conditions = list()
         for arg in args:
-            assert arg['symbol'] in symbol_map, '查询操作错误！正确操作包含：gt、lt等，详情见TreeModel使用手册'
-            assert arg['value_type'] in type_map, '查询数据类型！正确操作包含：str、int等，详情见TreeModel使用手册'
+            if arg['symbol'] not in symbol_map:
+                raise DataError('查询操作错误！正确操作包含：gt、lt等，详情见TreeModel使用手册')
+            if arg['value_type'] not in type_map:
+                raise DataError('查询数据类型！正确操作包含：str、int等，详情见TreeModel使用手册')
             data = {'name': arg['key'], 'nCondition': symbol_map[arg['symbol']], 'vLiData': arg['value'],
                     'vLiDataType': type_map[arg['value_type']]}
             if arg.get('range_conditions'):
